%Core system of nonlinear equations


function  f = NAWM_ss_equations(y, beta, kappa, zeta, gz, alpha, varphiH, varphiW,...
    muC, muI, sI, sG, sIMC ,sIMI, sX, pIM,...
    sIG,nuG, alphaG, nuK, KG_K_target, alphaK, b0,KY_target,dtx_ybar_target,...
    sC,sTR,omega,cJcISSratio,tauCrevYbar_target,tauWfrevYbar_target,...
    tauWhrevYbar_target,corp_gov_spread2,pibar,epsRPK2,given_alphaG,given_alphaK,alphaG_target,alphaK_target,varsigma)


%guesses
k     = exp(y( 1));
c     = exp(y( 2));
N     = exp(y( 3));
pI    = exp(y( 4));
psi   = exp(y( 5));
nuC   = exp(y( 6))/(1+exp(y( 6)));
nuI   = exp(y( 7))/(1+exp(y( 7)));
tauK  = y(8);
kG    = exp(y( 9));
deltaG= exp(y( 10))/(1+exp(y( 10)));
delta = exp(y( 11))/(1+exp(y( 11)));
tauN  = y(12);
cJ    = exp(y( 13));
cI    = exp(y( 14));
trJ   = y(15);
trI   = y(16);
tauC  = y(17);
tauWh = y(18);
tauWf = y(19);
alphaK= exp(y( 20))/(1+exp(y( 20)));
alphaG= exp(y( 21))/(1+exp(y( 21)));
corp_gov_spread=abs(y(22));


Rcorppbar      =corp_gov_spread/400+1+4.4/400;
epsRPK         =(1+4.4/400)/Rcorppbar;

%domestic homogenous good relative price
pH    = ((1-(1-nuC)*pIM^(1-muC))/nuC)^(1/(1-muC));

%composite capital stock
if nuK>1-1e-4 && nuK<1+1e-4
    ktilde= alphaK^(-alphaK)*(1-alphaK)^(-(1-alphaK))*k^alphaK*kG^(1-alphaK); %cobb douglas
else
    ktilde=( alphaK^(1/nuK)*k^( (nuK-1)/nuK )+ (1-alphaK)^(1/nuK)*kG^( (nuK-1)/nuK )     )^( nuK/(nuK-1) ); %CES
end

%relative price output and output
pY    = pH;
y     = (ktilde/gz)^alpha*N^(1-alpha)-psi;

%rel. price gov. cons and gov cons.
pG    = pH;
hG    = sG*pY*y/pG;

%gov. invest
pIG    = pH;
hIG    = sIG*pY*y/pIG;

%exports
x     = sX*y;  % because PX = PH = PY

%rental rate
rK    = 1/((1-tauK)*epsRPK)*(gz^varsigma/beta-(1-delta)*epsRPK-tauK*delta*epsRPK)*pI;

%labor market equilibrium coefficient
Xi    = gz*alpha/(1-alpha)*(1+tauC)/(1-tauN-tauWh)*(1-kappa/gz)*(1+tauWf)/(rK/pI)*varphiW*alphaG^(-1/nuG);

%time to build - outlay share
b1=1-b0;

%total utility valued consumption
if nuG>1-1e-4 && nuG<1+1e-4
    cItilde   = alphaG^(-alphaG)*(1-alphaG)^(-(1-alphaG))*cI^alphaG*hG^(1-alphaG); %cobb douglas
else
    cItilde   =( alphaG^(1/nuG)*cI^( (nuG-1)/nuG )+ (1-alphaG)^(1/nuG)*hG^(  (nuG-1)/nuG))^(nuG/(nuG-1));
end


%wage and direct tax revenues / wN
w= (1-alpha)/alpha*k/N/gz/(1+tauWf)*rK*(1+( (1-alphaK)/alphaK )^(1/nuK)*(kG/k)^( (nuK-1)/nuK ));
dtx_ybar_bar = (tauN*w*N+tauK*k/gz*(rK-delta*pI))/(y*pY);


%%%%%%%%%%%%%%%%%%%%%%
%system of equations%%
%%%%%%%%%%%%%%%%%%%%%%

%labor market
equ1= Xi*N^(zeta+1)*cI/k/pI*(cItilde/cI)^((nuG-1)/nuG) - 1 - ( (1-alphaK)/alphaK )^(1/nuK)*(kG/k)^( (nuK-1)/nuK ) ;

%capital market
equ2= alpha - gz^(alpha-1)*( (1+( (1-alphaK)/alphaK )^(1/nuK)*(kG/k)^( (nuK-1)/nuK ))/ktilde^alpha  )*rK*varphiH/pH*k/(N^(1-alpha));

%feasibility
equ3=((gz-1+delta)/gz*k)^(1-1/muI)*(1-(1-nuI)*(pIM/pI)^(1-muI))- nuI^(1/muI)*( gz^(-alpha)*N^(1-alpha)*ktilde^alpha-psi-x-nuC*pH^(-muC)*c-hG-hIG)^(1-1/muI);

%relative prices
equ4=pH/pI - ((1-(1-nuI)*(pIM/pI)^(1-muI))/nuI)^(1/(1-muI));

%zero profits
equ5=1-1/varphiH*(1+psi/y)*( alpha*(1+( (1-alphaK)/alphaK )^(1/nuK)*(kG/k)^( (nuK-1)/nuK ))^(-1)+1-alpha );

%priv. cons. import share
equ6=pIM*(1-nuC)*(pIM)^(-muC)*c/(pY*y)- sIMC;

%priv. invest. import share
equ7=pIM*(1-nuI)*(pIM/pI)^(-muI)*(1-(1-delta)/gz)*k/(pY*y) - sIMI;

%investment share
equ8=pI*(1-(1-delta)/gz)*k/(pY*y) - sI;

%pub. investment share
equ9=pIG*(1-(1-deltaG)/gz)*kG/(pY*y)*(b0*gz+b1) - sIG;

%depreciation rate public capital
equ10=deltaG-0.015;

%depreciation rate private capital
equ11=delta-0.015;

%direct tax revenues to ybar
equ12=dtx_ybar_bar-dtx_ybar_target;

%total consumption - ricardian and non-ricardian
equ13=(1-omega)*cI+omega*cJ-c;

%non-ricardian consumption
equ14=(1-tauN-tauWh)*w*N+trJ-(1+tauC)*cJ;

%total transfers - ricardian and non-ricaridan
equ15=(1-omega)*trI+omega*trJ-sTR*y*pY;

%cJ/cI ratio
equ16=cJ/cI-cJcISSratio;

%cons. tax revenues
equ17=tauCrevYbar_target-tauC*c/(pY*y);

%Employer SSC rev.
equ18=tauWfrevYbar_target-tauWf*w*N/(pY*y);

%Employee SSC rev.
equ19=tauWhrevYbar_target-tauWh*w*N/(pY*y);

%set alphaK to desired value
if given_alphaK==1,
    equ20=alphaK_target-alphaK;
else
    error('not implemented here');
end

%set alphaG to desired value
if given_alphaG==1,
    equ21=alphaG-alphaG_target;
else
    error('not implemented here');
end

%steady state capital tax rate
equ22=tauK-0.35;


%equations
f     = [equ1;equ2;equ3;equ4;equ5;equ6;equ7;equ8;equ9;equ10;equ11;...
    equ12;equ13;equ14;equ15;equ16;equ17;equ18;equ19;equ20;equ21;equ22];






